/**
 * Source: https://github.com/madrobby/keymaster/blob/3b1f2afabf1569848dea8b697ac418f19b601a30/keymaster.js
 */
export declare const KEY_MAP: {
    [code: string]: number;
};
/**
 * Valid modifier keys.
 */
export declare const MODIFIERS: number[];
/**
 * Continue propagating the event to older listeners.
 */
export declare const SHOULD_PROPAGATE: boolean;
/**
 * Stringify a keyboard event.
 */
export declare function keyboardEventCombo(e: KeyboardEvent): string;
/**
 * Map keys to string.
 */
export declare function stringifyKey(...keys: (string | number)[]): string;
/**
 * Keyboard event handler.
 */
export declare type KeyHandler = (e: KeyboardEvent, combo: string) => void | boolean;
/**
 * Keyboard shortcut map.
 */
export interface Shortcuts {
    [key: string]: KeyHandler;
}
/**
 * Create a listener function from shortcuts.
 */
export declare function createShortcuts(shortcuts: Shortcuts, returnValue?: boolean): KeyHandler;
/**
 * Check if a keyboard event originated from an input.
 */
export declare function isInputEvent(event: KeyboardEvent): boolean;
/**
 * Function to wrap listener by filtering input events.
 */
export declare function filterInputEvent(listener: KeyHandler): KeyHandler;
/**
 * Keyboard manager library for mapping key events.
 */
export declare class Keyboard {
    listeners: KeyHandler[];
    addListener(callback: KeyHandler): number;
    removeListener(callback: KeyHandler): number;
    getHandler(): (event: KeyboardEvent) => boolean | void;
    getListener(returnValue?: boolean): KeyHandler;
}
